Documentation
¶
Index ¶
- func AssertEqual(t *testing.T, exp, act *Session)
- type EventData
- type Session
- func (s *Session) NewStep(name string)
- func (s *Session) RecordEvent(user *domain.User, event string, data any)
- func (s *Session) SaveToFile(file string) error
- func (s *Session) SaveToFileShortened(file string) error
- func (s *Session) SetRecordEvents(events ...string)
- func (s *Session) UseShortener(event string, sh Shortener)
- func (s *Session) WaitNResponses(n uint32)
- type Shortener
- type Step
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertEqual ¶
Types ¶
type Session ¶
type Session struct {
Steps []*Step
// contains filtered or unexported fields
}
func LoadFromFile ¶
func (*Session) RecordEvent ¶
RecordEvent records an event for the current step Even if the event should not be recorded, the counter will increase
func (*Session) SaveToFile ¶
func (*Session) SaveToFileShortened ¶
func (*Session) SetRecordEvents ¶
func (*Session) UseShortener ¶
func (*Session) WaitNResponses ¶
WaitNResponses waits for n responses to be recorded with Session.RecordEvent
type Shortener ¶
func EventShortener ¶
Click to show internal directories.
Click to hide internal directories.